function area = areaOfRect(length,width)
%areaOfRect compute area of rectangle given length and width
%
% consumes: 
%     length: scalar number
%     width: scalar number
%
% produces:
%     area: scalar number
%     
% examples
%     >> areaOfRect(3,4)
%     ans = 12
%     >> areaOfRect(7,2)
%     ans = 14
%     
% P.Conrad  CISC106 06F
  
  area = length * width;
  return;
end % function
